@@ -34,10 +34,10 @@ class ExampleExporter : public cuc::ImportExportHandler
 public:
     ExampleExporter();
        
-public slots:
+public Q_SLOTS:
     Q_INVOKABLE void handle_import(cuc::Transfer*);
     Q_INVOKABLE void handle_export(cuc::Transfer*);
-    
+    Q_INVOKABLE void handle_share(cuc::Transfer*);
 };
 
 #endif // EXAMPLEEXPORTER_H
