@@ -18,6 +18,7 @@
 #define COM_UBUNTU_CONTENT_PLUGIN_H_
 
 #include <QQmlExtensionPlugin>
+#include <QQmlEngine>
 
 class ContentHub;
 
@@ -27,6 +28,7 @@ class ContentHubPlugin : public QQmlExtensionPlugin
     Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QQmlExtensionInterface")
 
 public:
+    void initializeEngine(QQmlEngine * engine, const char * uri);
     void registerTypes(const char *uri);
 
 private:
