@@ -36,7 +36,7 @@ void initTr(const char *domain, const char *localeDir)
     textdomain(domain);
 }
 
-QString _(const char *text, const char *domain)
+QString __(const char *text, const char *domain)
 {
     return QString::fromUtf8(dgettext(domain, text));
 }
