@@ -20,23 +20,39 @@
 #define HOOK_H
 
 #include <QObject>
+#include <QFileInfo>
+#include <com/ubuntu/content/peer.h>
 
 #include "registry.h"
 
+namespace com
+{
+namespace ubuntu
+{
+namespace content
+{
+namespace detail
+{
 class Hook : public QObject
 {
     Q_OBJECT
 public:
-    explicit Hook(QString app_id, QObject *parent = 0);
+    explicit Hook(QObject *parent = 0);
+    Hook(com::ubuntu::content::detail::PeerRegistry *registry, QObject *parent = 0);
+    ~Hook();
 
-public slots:
-    void return_error(QString err = "");
+public Q_SLOTS:
+    bool return_error(QString err = "");
     void run();
+    bool add_peer(QFileInfo);
 
 private:
-    QString app_id;
-    Registry* registry;
+    com::ubuntu::content::detail::PeerRegistry* registry;
     
 };
+}
+}
+}
+}
 
 #endif // HOOK_H
