@@ -29,12 +29,12 @@ struct MockedAppManager : public cua::ApplicationManager
     {
         using namespace ::testing;
 
-        ON_CALL(*this, invoke_application(_)).WillByDefault(Return(true));
+        ON_CALL(*this, invoke_application(_,_)).WillByDefault(Return(true));
         ON_CALL(*this, stop_application(_)).WillByDefault(Return(true));
-        ON_CALL(*this, is_application_started(_)).WillByDefault(Return(false));
+        ON_CALL(*this, is_application_started(_)).WillByDefault(Return(true));
     }
 
-    MOCK_METHOD1(invoke_application, bool(const std::string &));
+    MOCK_METHOD2(invoke_application, bool(const std::string &, gchar ** uris));
     MOCK_METHOD1(stop_application, bool(const std::string &));
     MOCK_METHOD1(is_application_started, bool(const std::string &));
 };
