@@ -35,7 +35,7 @@ class AutoSharer : public cuc::ImportExportHandler
 public:
     AutoSharer();
        
-public slots:
+public Q_SLOTS:
     Q_INVOKABLE void handle_import(cuc::Transfer*);
     Q_INVOKABLE void handle_export(cuc::Transfer*);
     Q_INVOKABLE void handle_share(cuc::Transfer*);
